@@ -1,3 +1,4 @@
+import matplotlib
 from matplotlib import pylab
 import numpy
 
@@ -7,6 +8,8 @@ Written: JULY 22, 2014
 Author Gen Del Raye
 '''
 
+matplotlib.rcParams['svg.fonttype'] = 'none' # Embed text instead of turning text to paths
+
 def square_factory(x, y, h, ax, color = 'red'):
     '''
     Add squares to plot
